@@ -2,7 +2,7 @@ mod utils;
 
 #[cfg(test)]
 mod trade {
-    use crypto_msg_parser::{parse_trade, MarketType, TradeSide};
+    use crypto_msg_parser::{extract_symbol, parse_trade, MarketType, TradeSide};
 
     #[test]
     fn inverse_future() {
@@ -16,6 +16,7 @@ mod trade {
                 "deribit",
                 MarketType::InverseFuture,
                 "BTC/USD".to_string(),
+                extract_symbol("deribit", MarketType::InverseFuture, raw_msg).unwrap(),
                 trade,
             );
         }
@@ -38,6 +39,7 @@ mod trade {
                 "deribit",
                 MarketType::InverseSwap,
                 "BTC/USD".to_string(),
+                extract_symbol("deribit", MarketType::InverseSwap, raw_msg).unwrap(),
                 trade,
             );
 
@@ -60,6 +62,7 @@ mod trade {
                 "deribit",
                 MarketType::EuropeanOption,
                 "BTC/BTC".to_string(),
+                extract_symbol("deribit", MarketType::EuropeanOption, raw_msg).unwrap(),
                 trade,
             );
 
@@ -74,7 +77,7 @@ mod trade {
 
 #[cfg(test)]
 mod l2_orderbook {
-    use crypto_msg_parser::{parse_l2, MarketType};
+    use crypto_msg_parser::{extract_symbol, parse_l2, MarketType};
 
     #[test]
     fn inverse_future_snapshot() {
@@ -89,6 +92,7 @@ mod l2_orderbook {
             "deribit",
             MarketType::InverseFuture,
             "BTC/USD".to_string(),
+            extract_symbol("deribit", MarketType::InverseFuture, raw_msg).unwrap(),
             orderbook,
         );
 
@@ -126,6 +130,7 @@ mod l2_orderbook {
             "deribit",
             MarketType::InverseSwap,
             "BTC/USD".to_string(),
+            extract_symbol("deribit", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
         );
 
@@ -163,6 +168,7 @@ mod l2_orderbook {
             "deribit",
             MarketType::InverseSwap,
             "BTC/USD".to_string(),
+            extract_symbol("deribit", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
         );
 
@@ -200,6 +206,7 @@ mod l2_orderbook {
             "deribit",
             MarketType::InverseSwap,
             "BTC/USD".to_string(),
+            extract_symbol("deribit", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
         );
 
@@ -237,6 +244,7 @@ mod l2_orderbook {
             "deribit",
             MarketType::EuropeanOption,
             "BTC/BTC".to_string(),
+            extract_symbol("deribit", MarketType::EuropeanOption, raw_msg).unwrap(),
             orderbook,
         );
 
